@@ -1,5 +1,3 @@
-/* $Id: wmesa.h,v 1.1.1.1.8.1 2002/04/23 18:24:41 kschultz Exp $ */
-
 /*
  * Mesa 3-D graphics library
  * Version:  3.0
@@ -22,32 +20,6 @@
  */
 
 
-/*
- * $Log: wmesa.h,v $
- * Revision 1.1.1.1.8.1  2002/04/23 18:24:41  kschultz
- * Fix up alpha buffer handling for Windows.
- * - add two new Pixel Format Descriptors that do not have alpha bits to
- * mirror the two that do.
- * - add logic to wglChoosePixelFormat to match PFD's with respect to alpha.
- * - Create/clear software alpha buffer as required.
- * Now a wgl or GLUT program can control the creation of a software alpha
- * buffer via the PFD or GLUT parms, respectively.
- *
- * Revision 1.1.1.1  1999/08/19 00:55:40  jtg
- * Imported sources
- *
- * Revision 3.2  1999/01/03 02:54:45  brianp
- * updated per Ted Jump
- *
- * Revision 3.1  1998/12/01 02:34:27  brianp
- * applied Mark Kilgard's patches from November 30, 1998
- *
- * Revision 3.0  1998/02/20 05:06:59  brianp
- * initial rev
- *
- */
-
-
 /*
  * Windows driver by: Mark E. Peterson (markp@ic.mankato.mn.us)
  * Updated by Li Wei (liwei@aiar.xjtu.edu.cn)
@@ -78,17 +50,19 @@ extern "C" {
 #endif
 
 
-#include "gl\gl.h"
+#include "GL/gl.h"
 
-#pragma warning (disable:4273)
-#pragma warning( disable : 4244 ) /* '=' : conversion from 'const double ' to 'float ', possible loss of data */
-#pragma warning( disable : 4018 ) /* '<' : signed/unsigned mismatch */
-#pragma warning( disable : 4305 ) /* '=' : truncation from 'const double ' to 'float ' */
-#pragma warning( disable : 4013 ) /* 'function' undefined; assuming extern returning int */
-#pragma warning( disable : 4761 ) /* integral size mismatch in argument; conversion supplied */
-#pragma warning( disable : 4273 ) /* 'identifier' : inconsistent DLL linkage. dllexport assumed */
-#if (MESA_WARNQUIET>1)
-#	pragma warning( disable : 4146 ) /* unary minus operator applied to unsigned type, result still unsigned */
+#if defined(_MSV_VER) && !defined(__GNUC__)
+#  pragma warning (disable:4273)
+#  pragma warning( disable : 4244 ) /* '=' : conversion from 'const double ' to 'float ', possible loss of data */
+#  pragma warning( disable : 4018 ) /* '<' : signed/unsigned mismatch */
+#  pragma warning( disable : 4305 ) /* '=' : truncation from 'const double ' to 'float ' */
+#  pragma warning( disable : 4013 ) /* 'function' undefined; assuming extern returning int */
+#  pragma warning( disable : 4761 ) /* integral size mismatch in argument; conversion supplied */
+#  pragma warning( disable : 4273 ) /* 'identifier' : inconsistent DLL linkage. dllexport assumed */
+#  if (MESA_WARNQUIET>1)
+#    pragma warning( disable : 4146 ) /* unary minus operator applied to unsigned type, result still unsigned */
+#  endif
 #endif
 
 /*
@@ -104,7 +78,7 @@ typedef struct wmesa_context *WMesaContext;
  * appropriate colormap.
  *
  * Input:
- *         hWnd - Window handle
+ *         hDC - Windows device or memory context
  *         Pal  - Palette to use
  *         rgb_flag - GL_TRUE = RGB mode,
  *                    GL_FALSE = color index mode
@@ -117,7 +91,7 @@ typedef struct wmesa_context *WMesaContext;
  *
  * Return:  a WMesa_context or NULL if error.
  */
-extern WMesaContext WMesaCreateContext(HWND hWnd,HPALETTE* pPal,
+extern WMesaContext WMesaCreateContext(HDC hDC,HPALETTE* pPal,
                                        GLboolean rgb_flag,
                                        GLboolean db_flag,
                                        GLboolean alpha_flag);
